//
//  AnimationComponent.m
//  SpaceInvadersTutorial
//
//  Created by Barbara Köhler on 6/16/13.
//  Copyright (c) 2013 Barbara Köhler. All rights reserved.
//

#import "AnimationComponent.h"

@implementation AnimationComponent

- (id)initWithTextureAtlas:(NSString*) textureAtlasName timePerFrame:(NSTimeInterval) sec {
    self = [self initWithTextureAtlas:textureAtlasName timePerFrame:sec shouldRepeat:YES];
    return self;
}

- (id)initWithTextureAtlas:(NSString*) textureAtlasName timePerFrame:(NSTimeInterval) sec shouldRepeat:(BOOL) repeats {
    self = [super init];
    if (self) {
        SKTextureAtlas* atlas = [SKTextureAtlas atlasNamed:textureAtlasName];
        NSArray* textureNames = [atlas.textureNames sortedArrayUsingSelector:@selector(localizedCaseInsensitiveCompare:)];
        NSMutableArray* minimizedTextureNames = [NSMutableArray arrayWithCapacity:[textureNames count]];
        
        // remove all naming extensions that have to do with availablity on different devices and resolutions
        for (NSString* textureName in textureNames) {
            NSString* minimizedTextureName = [textureName stringByReplacingOccurrencesOfString:@"@2x" withString:@""];
            minimizedTextureName = [minimizedTextureName stringByReplacingOccurrencesOfString:@"~iphone" withString:@""];
            minimizedTextureName = [minimizedTextureName stringByReplacingOccurrencesOfString:@"~ipad" withString:@""];
            if (![minimizedTextureNames containsObject:minimizedTextureName]) {
                [minimizedTextureNames addObject:minimizedTextureName];
            }
        }
        
        NSMutableArray* textureArray = [NSMutableArray arrayWithCapacity:[minimizedTextureNames count]];
        for (NSString* textureName in minimizedTextureNames) {
            SKTexture* texture = [atlas textureNamed:textureName];
            [textureArray addObject:texture];
        }
        SKAction* singleAnimation = [SKAction animateWithTextures:textureArray timePerFrame:sec];
        if (repeats) {
            _animation = [SKAction repeatActionForever:singleAnimation];
        } else {
            _animation = singleAnimation;
        }
    }
    return self;
}

- (id)initWithTextureAtlas:(NSString*)textureAtlasName withBaseImageName:(NSString*) baseImageName timePerFrame:(NSTimeInterval) sec {
    self = [self initWithTextureAtlas:textureAtlasName withBaseImageName:baseImageName timePerFrame:sec shouldRepeat:YES];
    return self;
}

- (id)initWithTextureAtlas:(NSString*)textureAtlasName withBaseImageName:(NSString*) baseImageName timePerFrame:(NSTimeInterval) sec shouldRepeat:(BOOL) repeats {
    self = [super init];
    if (self) {
        SKTextureAtlas* atlas = [SKTextureAtlas atlasNamed:textureAtlasName];
        NSArray* textureNames = atlas.textureNames;
        
        NSMutableArray* textureArray = [NSMutableArray arrayWithCapacity:10];
        for (int animationNumber = 1; ; animationNumber++) {
            NSString* filename = [NSString stringWithFormat: baseImageName, animationNumber];
            if ([textureNames containsObject:filename]) {
                SKTexture* texture = [atlas textureNamed:filename];
                [textureArray addObject:texture];
            } else {
                break;
            }
        }
        SKAction* singleAnimation = [SKAction animateWithTextures:textureArray timePerFrame:sec];
        _animation = [SKAction repeatActionForever:singleAnimation];
    }
    return self;
}

@end
